marktools.Articulation
======================

.. inheritance-diagram:: abjad.tools.marktools.Articulation.Articulation.Articulation
   :private-bases:

.. autoclass:: abjad.tools.marktools.Articulation.Articulation.Articulation

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.format

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.direction

   .. note:: Inherited from :py:class:`marktools._DirectedMark <abjad.tools.marktools._DirectedMark._DirectedMark._DirectedMark>`

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.name

Methods
-------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.attach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.detach

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__eq__

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__str__
